//**************************************************************
// LiteCAD Application Demo
// RecentList Unit
// harry200@gmail.com
//**************************************************************

unit RecentList;

interface

uses
  Windows, SysUtils, Classes, IniFiles, UIRibbon, UIRibbonCommands, Vcl.Forms;

  procedure LoadRecentList(const Ribbon:TUIRibbon);
  procedure SaveRecentList(const Ribbon:TUIRibbon);
  function  RecentFileExist(const Ribbon:TUIRibbon; RecentItem: ShortInt): Boolean;
  procedure AddFileToMRUList(const Ribbon:TUIRibbon; const FileName: String);
  procedure ChangePositionFileInMRUList(const Ribbon:TUIRibbon; const FileName: String; MRUListItem: ShortInt);

  var
    MRUList: TStringList;

  const
    MaxMRUCount   = 9;                       // max files in recent list
    MRUSection    = 'FileHistory';           // section name (mru.list)
    MRUKey        = 'File';                  // key section (mru.list)
    fnMRU         = 'Config\LitecadApp.mru'; // recent files

implementation

{$REGION 'Working with Recent List'}

// Load recent items from mru.list
procedure LoadRecentList(const Ribbon:TUIRibbon);
  var
    Ini: TIniFile;
    i: Integer;
    RecentFileName: String;
begin
  MRUList.Clear;
  InI:= TIniFile.Create(ExtractFilePath(ParamStr(0))+fnMRU);
  try
    for i:=0 to Pred(MaxMRUCount) do
      begin
        RecentFileName:=Ini.ReadString(MRUSection,MRUKey+IntToStr(i),'');
        if RecentFileName<>''
          then
            begin
              MRUList.Add(RecentFileName);
              Ribbon.RecentItems.Add(ExtractFileName(RecentFileName),RecentFileName)
            end
          else break
      end
  finally
    FreeAndNil(Ini)
  end;
end;

// Save recent items to mru.list
procedure SaveRecentList(const Ribbon:TUIRibbon);
  var
    i:   Integer;
    Ini: TIniFile;
begin
  Ribbon.RecentItems.Items.Clear;
  Ini:= TIniFile.Create(ExtractFilePath(ParamStr(0))+fnMRU);
  with Ini do
  try
    EraseSection(MRUSection);
    for i:=0 to Pred(MRUList.Count) do
      begin
        WriteString(MRUSection,MRUKey + IntToStr(i),MRUList[i]);
        Ribbon.RecentItems.Add(ExtractFileName(MRUList[i]),MRUList[i])
      end;
  finally
    FreeAndNil(Ini)
  end;
end;

// Check recent file exists
function RecentFileExist(const Ribbon:TUIRibbon; RecentItem: ShortInt): Boolean;
  var FileName: String;
begin
  FileName:=MRUList[RecentItem];
  if FileExists(FileName)
    then Result:=true
    else
      begin
        Result:=false;
        MRUList.Delete(RecentItem);
        SaveRecentList(Ribbon);
        Application.MessageBox(PChar('File: '+FileName+' does not exist!'),'Warning!',MB_ICONINFORMATION);
      end
end;

// Add file to recent list (mru.list)
procedure AddFileToMRUList(const Ribbon:TUIRibbon; const FileName: String);
  var i : Integer;
begin
  if MRUList.Count=0 then MRUList.Add(FileName)
    else
      begin
        if MRUList.Count<MaxMRUCount then
          begin
            MRUList.Add('');
            for i:=Pred(MRUList.Count)-1 downto 0 do MRUList[i+1]:=MRUList[i];
          end
            else
              for i:=Pred(MRUList.Count)-1 downto 0 do MRUList[i+1]:=MRUList[i];
        MRUList[0]:=FileName
      end;
  SaveRecentList(Ribbon);
end;

// Chenge file position in recent list
procedure ChangePositionFileInMRUList(const Ribbon:TUIRibbon; const FileName: String; MRUListItem: ShortInt);
  var i: Integer;
begin
  if MRUListItem>MaxMRUCount then exit;
  for i:=Pred(MRUListItem) downto 0 do MRUList[i+1]:=MRUList[i];
  MRUList[0]:=FileName;
  SaveRecentList(Ribbon);
end;

{$ENDREGION 'Working with Recent List'}

end.
